@@ -115,6 +115,7 @@ KPluginFactory *KPluginLoader::factory()
     return factory;
 }
 
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 84)
 quint32 KPluginLoader::pluginVersion()
 {
     Q_D(const KPluginLoader);
@@ -124,6 +125,7 @@ quint32 KPluginLoader::pluginVersion()
     }
     return d->pluginVersion;
 }
+#endif
 
 QString KPluginLoader::pluginName() const
 {
@@ -268,14 +270,19 @@ void KPluginLoader::forEachPlugin(const QString &directory, std::function<void(c
 QVector<KPluginMetaData> KPluginLoader::findPlugins(const QString &directory, std::function<bool(const KPluginMetaData &)> filter)
 {
     QVector<KPluginMetaData> ret;
+    QSet<QString> addedPluginIds;
     forEachPlugin(directory, [&](const QString &pluginPath) {
         KPluginMetaData metadata(pluginPath);
         if (!metadata.isValid()) {
             return;
         }
+        if (addedPluginIds.contains(metadata.pluginId())) {
+            return;
+        }
         if (filter && !filter(metadata)) {
             return;
         }
+        addedPluginIds << metadata.pluginId();
         ret.append(metadata);
     });
     return ret;
